#include "lcd.h"
#include "sensors.h"
#include "setup.h"

/**
 * @brief Collects data from sensors and turns on outputs if needed.
 *
 */
void collectData()
{
	waitingEffect("Collecting  data", 500);

	readLight();
	readTemperature();
	readHumidity();
	readMoisture();
}

/**
 * @brief Timer interrupt routine.
 *
 */
ISR(TIMER1_COMPA_vect)
{
	/* increments circuit timers */
	timer++;
	waterTimer++;
	fanTimer++;
}

void setup()
{
	setupDigital();
	setupSensors();
	setupTimer();

	Serial.begin(9600);

	initialLcdMessage();
	collectData();
}

void loop()
{
	/* fan has been on for a period of time */
	if (fanOn) {
		if (fanTimer >= FAN_ON) {
			fanOn = false;

			/* starts timer for measuring fan off */
			fanTimer = 0;

			/* turns off the fan */
			digitalWrite(FAN, LOW);
		}
	}

	/* collects new data every minute */
	if (timer >= COLLECT_DATA) {
		collectData();

		/* starts timer for measuring time between collecting data */
		timer = 0;
	} else {
		displayCollectedData();
	}
}
